cd "$dataPath/ConstructedData"
set more off
use panel_use, clear

sort msa_num time
xtset msa_num time
*1st stage
foreach y in lrhpi lrhpi_unaval lrhpi_wrluri {
ivreghdfe `y' group#c.(l1.lpermits $ctrls lprop_crime lprop_crime_wrluri lprop_crime_unaval lrinc lrinc_wrluri lrinc_unaval) if (dum06 == 1 | dum19==1) & sample== 1 & wrluri != . & unaval != ., robust absorb(group##msa_num time)
g in_sample_`y' =  e(sample)
predict `y'_fit if in_sample_`y' == 1
replace `y'_fit = . if in_sample_`y' == 0
}

*2nd stage
xtset msa_num time
ivreghdfe lpermits group#c.(l1.lpermits $ctrls lrhpi_fit lrhpi_unaval_fit lrhpi_wrluri_fit) if (dum06 == 1 | dum19==1) &  sample==1, robust absorb(msa_num time)

sum wrluri if dum06 == 1 | dum19 == 1, det
local med_wrluri = round(r(p50),0.01)
sum unaval if dum06 == 1 | dum19 == 1, det
local med_unaval = round(r(p50),0.01)

lincom (_b[1.group#c.lrhpi_fit] + _b[1.group#c.lrhpi_unaval_fit]*`med_unaval' + _b[1.group#c.lrhpi_wrluri_fit]*`med_wrluri') - (_b[2.group#c.lrhpi_fit] + _b[2.group#c.lrhpi_unaval_fit]*`med_unaval' + _b[2.group#c.lrhpi_wrluri_fit]*`med_wrluri') 

***Lage box-plot

replace elast = _b[1.group#c.lrhpi_fit] + _b[1.group#c.lrhpi_unaval_fit]*unaval + _b[1.group#c.lrhpi_wrluri_fit]*wrluri if group == 1 & in_sample_lrhpi_unaval != 0 & in_sample_lrhpi_wrluri != 0
replace elast = _b[2.group#c.lrhpi_fit] + _b[2.group#c.lrhpi_unaval_fit]*unaval + _b[2.group#c.lrhpi_wrluri_fit]*wrluri if group == 2 & in_sample_lrhpi_unaval != 0 & in_sample_lrhpi_wrluri != 0


tabstat elast if group ==  1,stat(p10 p50 p90) format(%9.2f)
tabstat elast if group ==  2,stat(p10 p50 p90) format(%9.2f)

replace elast = 0 if elast < 0 

g elast06_help = elast if group == 2
bysort msa_num : egen elast06 = median(elast06_help)
g elast19_help = elast if group == 1
bysort msa_num : egen elast19 = median(elast19_help)


g Delast = elast19-elast06

bysort msa_num : g dup_msa = _n
keep if dup_msa == 1


preserve 
keep msa_num elast06
ren elast06 elast
g cate = 1 
save elast06_const_FE, replace
restore

preserve 
keep msa_num elast19
ren elast19 elast
g cate = 2 
save elast19_const_FE, replace
restore

preserve 
keep msa_num Delast
ren Delast elast
g cate = 3
save Delast_const_FE, replace
restore

use elast06_const_FE, clear
append using elast19_const_FE
append using Delast_const_FE

label define cate 1 "1996-2006", replace
label define cate 2 "2012-2019", add
label define cate 3 "Change", add
label val cate cate

sum elast if cate == 1, det
local med_elast06 = round(r(p50),0.01)
sum elast if cate == 2, det
local med_elast19 = round(r(p50),0.01)
sum elast if cate == 3, det
local med_delast = round(r(p50),0.01)

egen median_elast = median(elast), by(cate)
replace median_elast = round(median_elast,0.001) 
gen cate2 = cate + 0.45
gen showmedian = string(median_elast, "%9.2f") 


stripplot elast, over(cate) box(fcolor(eltblue) barw(0.5) ) vertical ms(none) pctile(10) ///
addplot(scatter median_elast cate2, ms(none ..)  mlabsize(*1.2) mlabpos(9) ///
mla(showmedian) mlabcolor(black..)) xsc(r(. 1.2)) xla(, noticks)  yli(0)   ytitle("Elasticity") yla(-3 "-3" -2 "-2" -1 "-1" 0 "0" 1 "1" 2 "2" 3 "3" 4 "4") note("") xtitle("")
cd "$outputFigures"
graph export "Figure_C2.pdf", replace

