*BARTIK APPROACH
cd "$dataPath/ConstructedData"
set more off
use panel_use, clear


*Guren, McKay, Nakamura and Steinsson (2021,Restud): instrument local house prices ///
*by taking the estimated house price sensitivity of each area to regional house prices

sort msa_num time

*Income share within each 9 Census divisions, 4 regions, and 51 states
bysort division time : egen inc_division = sum(totinc) 
g inc_division_shr = totinc/inc_division 

*Regional indices constructed by weighting MSA indices with income shares
gen rhpi_division_w = rhpi*inc_division_shr 
bysort division time : egen rhpi_division_w_tot= total(rhpi_division_w) 

*Exclude MSA i from the regional index associated with MSA i
gen rhpi_division_w_tot_i = rhpi_division_w_tot - cond(missing(rhpi_division_w), 0, rhpi_division_w) 

**Construct growth rates
xtset msa_num time
gen lrhpi_division_w_tot_i = log(rhpi_division_w_tot_i)
gen dlrhpi_division_w_tot_i = (lrhpi_division_w_tot_i-l1.lrhpi_division_w_tot_i)*100 if l1.lrhpi_division_w_tot_i!=.

**Constructing betas to collect Bartik instruments
g beta = .
foreach v in dlrhpi dlrhpi_unaval dlrhpi_wrluri {
	gen beta_`v' = .
}

*Sensitivty of MSA house prices to regional house prices
local ctrls_dif "dlrwage dlrinc dur dlpop dlcpi" 

sort msa_num time
xtset msa_num time
foreach z in dum06 dum19{
forval i=1/254{
	capture reg dlrhpi dlrhpi_division_w_tot_i `ctrls_dif' if sample==1 & `z'==1 & msa_num==`i',robust

	capture replace beta =_b[dlrhpi_division_w_tot_i] if sample==1 & `z'==1 & msa_num==`i' & e(sample)
	capture replace beta_dlrhpi =beta*dlrhpi_division_w_tot_i if sample==1 & `z'==1 & msa_num==`i' & e(sample)
}
}

foreach v in unaval wrluri {
	replace beta_dlrhpi_`v' = beta_dlrhpi*`v'
}


***Do our baseline regression using the Bartik-type instruments. The  show boxplots of implied elasticities for the two booms
eststo clear
xtset msa_num time
foreach z in dum06 dum19 {
sort msa_num time

sort msa_num time
ivreghdfe lpermits l(1/1).lpermits $ctrls  (lrhpi lrhpi_unaval lrhpi_wrluri = beta_dlrhpi beta_dlrhpi_wrluri beta_dlrhpi_unaval) if `z'==1 & sample==1  & lprop_crime!=., robust absorb(msa_num time)

g in_sample =  e(sample)
bysort msa_num in_sample: g msa_nr = _n 
g msa_`z' = (msa_nr == 1 & in_sample == 1)
qui replace elast =_b[lrhpi] + _b[lrhpi_unaval]*unaval + _b[lrhpi_wrluri]*wrluri if `z'==1 & sample==1 & in_sample == 1
tabstat elast if `z'==1,stat(p10 p50 p90) format(%9.2f)
drop in_sample msa_nr 
}

replace elast = 0 if elast < 0

g elast06_help = elast if msa_dum06  == 1 
bysort msa_num : egen elast06 = median(elast06_help)
g elast19_help = elast if msa_dum19 == 1
bysort msa_num : egen elast19 = median(elast19_help)

bysort msa_num : g dup_msa = _n
keep if dup_msa == 1

g Delast = elast19-elast06


preserve 
keep msa_num msa elast06
ren elast06 elast
g cate = 1 
save elast06_bartik, replace
restore

preserve 
keep msa_num elast19
ren elast19 elast
g cate = 2 
save elast19_bartik, replace
restore

preserve 
keep msa_num Delast
ren Delast elast
g cate = 3
save Delast_bartik, replace
restore

use elast06_bartik, clear
append using elast19_bartik
append using Delast_bartik


label define cate 1 "1996-2006", replace
label define cate 2 "2012-2019", add
label define cate 3 "Change", add
label val cate cate

sum elast if cate == 1, det
local med_elast06 = round(r(p50),0.01)
sum elast if cate == 2, det
local med_elast19 = round(r(p50),0.01)
sum elast if cate == 3, det
local med_delast = round(r(p50),0.01)

egen median_elast = median(elast), by(cate)
replace median_elast = round(median_elast,0.001) 
gen cate2 = cate + 0.45
gen showmedian = string(median_elast, "%9.2f") 

stripplot elast, over(cate) box(fcolor(eltblue) barw(0.5) ) vertical ms(none) pctile(10) ///
addplot(scatter median_elast cate2, ms(none ..)  mlabsize(*1.2) mlabpos(9) ///
mla(showmedian) mlabcolor(black..)) xsc(r(. 1.2)) xla(, noticks)  yli(0)   ytitle("Elasticity") yla(-5 "-5" -4 "-4" -3 "-3" -2 "-2" -1 "-1" 0 "0" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5") note("") xtitle("")

cd "$outputFigures"
graph export "Figure_C3.pdf", replace




