cd "$dataPath/ConstructedData"
set more off
use panel_use, clear

ivreghdfe lpermits l(1/1).lpermits $ctrls_no_int (lrhpi = lprop_crime lrinc) if sample==1 & dum19 == 1, robust absorb(msa_num time)
g in_sample1 =  e(sample)
sort msa_num time
bysort msa_num in_sample1 : g msa_nr1 = _n 
g msa_dum1 = (msa_nr1 == 1 & in_sample1 == 1)
bysort statenr : egen msas_in_state1 = total(msa_dum1)

sort msa_num time 
ivreghdfe lpermits l(1/1).lpermits $ctrls_no_int (lrhpi = lprop_crime lrinc) if sample==1 & dum06 == 1, robust absorb(msa_num time)
g in_sample2 =  e(sample)
sort msa_num time
bysort msa_num in_sample2 : g msa_nr2= _n 
g msa_dum2 = (msa_nr2 == 1 & in_sample2 == 1)
bysort statenr : egen msas_in_state2 = total(msa_dum2)

bysort msa_num  : egen sample1 = max(msa_dum1)
bysort msa_num  : egen sample2 = max(msa_dum2)

**Keep only MSAs present in both samples
g both_samples = (sample1 + sample2 == 2)
keep if both_samples == 1

sort msa_num time 
ivreghdfe lpermits l(1/1).lpermits $ctrls_no_int (lrhpi = lprop_crime lrinc) if sample==1 & dum19 == 1, robust absorb(msa_num time)
g in_sample =  e(sample)
sort msa_num time
bysort msa_num in_sample : g msa_nr = _n 
g msa_dum = (msa_nr == 1 & in_sample == 1)
bysort statenr : egen msas_in_state = total(msa_dum)

global ctrls3 "lrwage_unaval lrwage_wrluri ur lpop dep_ratio black_pop hispan_pop dlcpi dom_mig_pop int_mig_pop dlrmort_org l1.dlrinc_cap cv_inc_cap20"


*** Testing for equality in supply elasticities **
sort msa_num time
forvalues j=1(1)10 {
preserve
drop if msas_in_state <= `j'
ivreghdfe lpermits group#c.(l(1/1).lpermits $ctrls3)  (group#c.(lrhpi lrhpi_unaval lrhpi_wrluri) = group#c.(lprop_crime lprop_crime_wrluri lprop_crime_unaval lrinc lrinc_wrluri lrinc_unaval)) if (dum06 == 1 | dum19==1) & sample==1,robust absorb(group##msa_num statenr#time)

replace elast = _b[1.group#c.lrhpi] + _b[1.group#c.lrhpi_unaval]*unaval + _b[1.group#c.lrhpi_wrluri]*wrluri  if group == 1
replace elast = _b[2.group#c.lrhpi] + _b[2.group#c.lrhpi_unaval]*unaval + _b[2.group#c.lrhpi_wrluri]*wrluri  if group == 2

replace elast = 0 if elast < 0

g elast06_help = elast if group == 2
bysort msa_num : egen elast06 = median(elast06_help)
g elast19_help = elast if group == 1
bysort msa_num : egen elast19 = median(elast19_help)

bysort msa_num : g dup_msa = _n
keep if dup_msa == 1

g Delast = elast19 - elast06

keep Delast msa_num elast19 elast06 msa_name
g cate = `j' 
save elasticities_`j'_msas_in_state, replace
restore 
}


use elasticities_1_msas_in_state, clear
forvalues j=2(1)10 {
append using elasticities_`j'_msas_in_state
}

preserve
label define cate 1  "1", replace
label define cate 2  "2" , add
label define cate 3  "3" , add
label define cate 4  "4" , add
label define cate 5  "5" , add
label define cate 6  "6" , add
label define cate 7  "7" , add
label define cate 8  "8" , add
label define cate 9  "9" , add
label define cate 10 "10", add
label val cate cate

egen median_elast = median(Delast), by(cate)
replace median_elast = round(median_elast,0.001) 
gen cate2 = cate + 1
gen showmedian = string(median_elast, "%9.2f") 
g cate3 = 1

stripplot Delast, over(cate) box(fcolor(eltblue) barw(0.6) ) vertical ms(none) pctile(10) ///
addplot(scatter median_elast cate2, ms(none ..)  mlabsize(*1.2) mlabpos(9) ///
mla(showmedian) mlabcolor(black..)) xsc(r(. 1.2)) xla(, noticks)  yli(0)   ytitle("Change in elasticity") yla(-5 "-5" -4 "-4" -3 "-3" -2 "-2" -1 "-1" 0 "0") note("") xtitle("")
cd "$outputFigures"
graph export "Figure_C5.pdf", replace

restore


