cd "$dataPath/ConstructedData"
set more off
use panel_use, clear

sort msa_num time

*10-year
eststo clear
xtset msa_num time
forval i=1997(1)2010{
local aux_year=`i'+9

ivreghdfe lpermits l(1/1).lpermits $ctrls  (lrhpi lrhpi_unaval lrhpi_wrluri = lprop_crime lprop_crime_wrluri lprop_crime_unaval lrinc lrinc_wrluri lrinc_unaval) if year>=`i' & year<=`aux_year' & sample==1, robust absorb(msa_num time)

qui replace elastroll10 =_b[lrhpi] + _b[lrhpi_unaval]*unaval + _b[lrhpi_wrluri]*wrluri if year>=`i' & year<=`aux_year' & sample==1
qui replace elastupproll10 =_b[lrhpi] + 1.645*_se[lrhpi]	+ (_b[lrhpi_unaval] + 1.645*_se[lrhpi_unaval])*unaval + (_b[lrhpi_wrluri] + 1.645*_se[lrhpi_wrluri])*wrluri if year>=`i' & year<=`aux_year' & sample==1
qui replace elastlowroll10 =_b[lrhpi] - 1.645*_se[lrhpi]	+ (_b[lrhpi_unaval] - 1.645*_se[lrhpi_unaval])*unaval + (_b[lrhpi_wrluri] - 1.645*_se[lrhpi_wrluri])*wrluri if year>=`i' & year<=`aux_year' & sample==1
}
replace elastroll10 = 0 if elastroll10<0

qui forval i=1997/2010{
qui foreach v in elastroll10 elastupproll10 elastlowroll10{
	sum `v' if year==`i',detail
	replace `v'_p10 = r(p10) if year==`i'
	replace `v'_p50 = r(p50) if year==`i'
	replace `v'_p90 = r(p90) if year==`i'
}
}


*15-year
eststo clear
xtset msa_num time
forval i=1997(1)2005{
local aux_year=`i'+14
ivreghdfe lpermits l(1/1).lpermits $ctrls  (lrhpi lrhpi_unaval lrhpi_wrluri = lprop_crime lprop_crime_wrluri lprop_crime_unaval lrinc lrinc_wrluri lrinc_unaval) if year>=`i' & year<=`aux_year' & sample==1, robust absorb(msa_num time)

qui replace elastroll15 =_b[lrhpi] + _b[lrhpi_unaval]*unaval + _b[lrhpi_wrluri]*wrluri if year>=`i' & year<=`aux_year' & sample==1
qui replace elastupproll15 =_b[lrhpi] + 1.645*_se[lrhpi]	+ (_b[lrhpi_unaval] + 1.645*_se[lrhpi_unaval])*unaval + (_b[lrhpi_wrluri] + 1.645*_se[lrhpi_wrluri])*wrluri if year>=`i' & year<=`aux_year' & sample==1
qui replace elastlowroll15 =_b[lrhpi] - 1.645*_se[lrhpi]	+ (_b[lrhpi_unaval] - 1.645*_se[lrhpi_unaval])*unaval + (_b[lrhpi_wrluri] - 1.645*_se[lrhpi_wrluri])*wrluri if year>=`i' & year<=`aux_year' & sample==1
}

replace elastroll15 = 0 if elastroll10<0

qui forval i=1997/2005{
qui foreach v in elastroll15 elastupproll15 elastlowroll15{
	sum `v' if year==`i',detail
	replace `v'_p10 = r(p10) if year==`i'
	replace `v'_p50 = r(p50) if year==`i'
	replace `v'_p90 = r(p90) if year==`i'
}
}


bysort year: g dup_obs = _n
keep if dup_obs == 1


keep year elastupproll10_p50 elastlowroll10_p50 elastroll10_p50 elastupproll15_p50 elastlowroll15_p50 elastroll15_p50 zero

*Figure with confidence bands
*10-year
tsset year
set scheme s1mono
twoway (rarea elastupproll10_p50 elastlowroll10_p50 year if tin(1997,2010), color(gs14) xtitle("")) ///
(line elastroll10_p50 year if tin(1997,2010), color(navy)) ///
(line zero year if tin(1997,2010), lcolor(black) lwidth(vthin) lpattern(dash)), ///
xlabel(1997 "97-06" 1998 "98-07" 1999 "99-08" 2000 "00-09" 2001 "01-10" 2002 "02-11" ///
2003 "03-12" 2004 "04-13" 2005 "05-14" 2006 "06-15" 2007 "07-16" 2008 "08-17" 2009 "09-18" ///
2010 "10-19", labsize(small)) ///
title("10-year rolling window") legend(off) graphregion(fcolor(white)) name(roll10, replace) 

*15-year
set scheme s1mono
twoway (rarea elastupproll15_p50 elastlowroll15_p50 year if tin(1997,2005), color(gs14) xtitle("")) ///
(line elastroll15_p50 year if tin(1997,2005), color(navy)) ///
(line zero year if tin(1997,2005), lcolor(black) lwidth(vthin) lpattern(dash)), ///
xlabel(1997 "97-11" 1998 "98-12" 1999 "99-13" 2000 "00-14" 2001 "01-15" 2002 "02-16" 2003 ///
"03-17" 2004 "04-18" 2005 "05-19", labsize(small)) ///
title("15-year rolling window") legend(off) graphregion(fcolor(white)) name(roll15, replace) 

graph combine roll10 roll15, cols(2) xsize(5.5) ysize(2.5)

cd "$outputFigures"
graph export "Figure_C6.pdf", replace


