cd "$codePath"
do "Data transformations LP.do" 
set more off

*For bootstrap
gen newid = msa_num
global elast06_val=elast06_med
global elast19_val=elast19_med
global delast19_val=-delast_booms_med

sort msa_num time
xtset msa_num time

tsset newid time

capture program drop bsivreghdfe
program bsivreghdfe, eclass
ivreghdfe `0'
matrix b = e(b)
tempvar smp
qui: gen `smp'= e(sample)
ereturn post b, esample(`smp')
end

set rmsg on
timer clear
foreach y in $depvar {
timer on 1
forval j=0/${hor}{
local ord=`h'+1 
bootstrap, reps(${M}) cl(msa_num) idcl(newid): qui bsivreghdfe d`j'l`y'_cum $ctrls_lp (dus_gs1 dus_gs1_elast = ffs3m_shock ffs3m_shock_elast) l(1/4).ffs3m_shock l(1/4).ffs3m_shock_elast if smpl_booms==1, robust cl(msa_num) small absorb(msa_num) 
	
	
*Flip the sign because a negative shock is expansionary
	qui lincom (dus_gs1  + (dus_gs1_elast)*($elast06_val))*(-1)
	qui replace betamid06_`y' = r(estimate) if h==`j'
	qui replace betaupp06_`y' = r(estimate) + 1.645*r(se) if h==`j'
	qui replace betalow06_`y' = r(estimate) - 1.645*r(se) if h==`j'

	qui lincom (dus_gs1  + (dus_gs1_elast)*($elast19_val))*(-1)
	qui replace betamid19_`y' = r(estimate) if h==`j'
	qui replace betaupp19_`y' = r(estimate) + 1.645*r(se) if h==`j'
	qui replace betalow19_`y' = r(estimate) - 1.645*r(se) if h==`j'

	qui lincom (dus_gs1_elast)*($delast19_val)
	qui replace betamidbooms_`y' = r(estimate) if h==`j'
	qui replace betauppbooms_`y' = r(estimate) + 1.645*r(se) if h==`j'
	qui replace betalowbooms_`y' = r(estimate) - 1.645*r(se) if h==`j'
}
timer off 1
}
timer list
set rmsg off


************************
**** FIGURES: IRF ******
************************

*Across booms with confidence bands
set scheme s1mono
local dum1 "06"
local dum2 "19"
foreach y in rhpi permits_4ma{
	twoway rarea betaupp`dum1'_`y' betalow`dum1'_`y' 		    h if h>=0 & h<=${hor} & msa_num == 5, color(gs14) xtitle("") xlabel(0(4)$hor) || ///
	line betamid`dum1'_`y' 							   		    h if h>=0 & h<=${hor} & msa_num == 5, color(navy) lpattern(solid dash) || ///
	line betamid`dum2'_`y' betaupp`dum2'_`y' betalow`dum2'_`y'  h if h>=0 & h<=${hor} & msa_num == 5, color(cranberry cranberry cranberry) lpattern(solid dash dash) || ///
	line zero 												    h if h>=0 & h<=${hor} & msa_num == 5, color(black) lpattern(solid) lwidth(vthin) ///
	graphregion(fcolor(white)) title(`: variable label `y'') name(`y', replace) legend(order(2 "`: variable label dum`dum1''" 3 "`: variable label dum`dum2''") pos(11) ring(0) size(small) rows(2)) nodraw
	local `y'1 ``y'' `y'
}
graph combine `rhpi1' `permits_4ma1', row(2) name(booms, replace) nodraw

*Graphs with differential impacts across booms
foreach y in rhpi permits_4ma{
	twoway rarea betauppbooms_`y' betalowbooms_`y' 		   	   h if h>=0 & h<=${hor} & msa_num == 5, color(gs14) xtitle("") xlabel(0(4)$hor) || ///
	line betamidbooms_`y' 							   		   h if h>=0 & h<=${hor} & msa_num == 5, color(navy) lpattern(solid dash) || ///
	line zero 												   h if h>=0 & h<=${hor} & msa_num == 5, color(black) lpattern(solid) lwidth(vthin) ///
	graphregion(fcolor(white)) title(Differential effect between booms) name(`y', replace) legend(off) nodraw
	local `y'2 ``y'' `y'
	}
graph combine `rhpi2' `permits_4ma2', row(2) name(dif, replace) nodraw

*Combine both graphs
graph combine booms dif,
graph display

cd "$outputFigures"
graph export "Figure_5_one_year_rate.pdf", replace
