cd "$codePath"
do "Data transformations LP.do" 
set more off

qui foreach v in betamid beta betaupp betalow {
qui foreach w in rhpi permits_4ma {
qui foreach x in ffr_sw fg_sw lsap_sw {
	gen `v'booms_`w'_`x' =.
	gen `v'06_`w'_`x'    =.
	gen `v'19_`w'_`x'    =.
}
}
}

gen newid = msa_num

global alt "ffr_sw fg_sw lsap_sw" 
global depvar "rhpi permits_4ma" 
global elast06_val=elast06_med
global elast19_val=elast19_med
global delast19_val=-delast_booms_med

sort msa_num time
tsset newid time

capture program drop bsivreghdfe
program bsivreghdfe, eclass
ivreghdfe `0'
matrix b = e(b)
tempvar smp
qui: gen `smp'= e(sample)
ereturn post b, esample(`smp')
end

set rmsg on
timer clear


foreach spec in $alt {
timer on 1
foreach y in $depvar {
forval j=0/${hor}{
local ord=`h'+1 

bootstrap, reps($M) cl(msa_num) idcl(newid): qui bsivreghdfe d`j'l`y'_cum $ctrls_lp (dus_gs2 dus_gs2_elast = `spec' `spec'_elast) l(1/4).`spec' l(1/4).`spec'_elast if smpl_booms==1, robust cl(msa_num) small absorb(msa_num) 
	
*Flip the sign because a negative shock is expansionary
	qui lincom (dus_gs2 + dus_gs2_elast*$elast06_val)*(-1)
	qui replace betamid06_`y'_`spec'  = r(estimate) if h==`j'
	qui replace betaupp06_`y'_`spec'  = r(estimate) + 1.645*r(se) if h==`j'
	qui replace betalow06_`y'_`spec'  = r(estimate) - 1.645*r(se) if h==`j'

	qui lincom (dus_gs2   + dus_gs2_elast*$elast19_val)*(-1)
	qui replace betamid19_`y'_`spec'  = r(estimate) if h==`j'
	qui replace betaupp19_`y'_`spec'  = r(estimate) + 1.645*r(se) if h==`j'
	qui replace betalow19_`y'_`spec'  = r(estimate) - 1.645*r(se) if h==`j'

	qui lincom dus_gs2_elast*$delast19_val
	qui replace betamidbooms_`y'_`spec'  = r(estimate) if h==`j'
	qui replace betauppbooms_`y'_`spec'  = r(estimate) + 1.645*r(se) if h==`j'
	qui replace betalowbooms_`y'_`spec'  = r(estimate) - 1.645*r(se) if h==`j'
}
timer off 1
}
}
timer list
set rmsg off

preserve
bysort time : g dup_time = _n 
keep if dup_time == 1

*Plot chart with all specs
set scheme s1mono
foreach dum in 06 19{
	twoway line betamid`dum'_rhpi_ffr_sw betamid`dum'_rhpi_fg_sw betamid`dum'_rhpi_lsap_sw h if h>=0 & h<=${hor}, ///
	color(navy cranberry dkorange) lwidth(medthick medium medium) lpattern(solid longdash shortdash) xtitle("") xlabel(0(4)$hor) || ///
	line zero 												    h if h>=0 & h<=${hor}, color(black) lpattern(solid) lwidth(vthin) ///
	graphregion(fcolor(white)) title(`: variable label dum`dum'', size(medsmall)) name(rhpi`dum', replace) legend(order(1 "FFR" 2 "FG" 3 "LSAP") pos(11) ring(0) size(vsmall) rows(5)) nodraw
	local rhpi`dum' `rhpi`dum'' rhpi`dum'
}

graph combine `rhpi19' `rhpi06', col(2) ycommon name(rhpi_robust, replace) xsize(5) ysize(7) title(Real house prices, size(medsmall))   

foreach dum in 06 19{
	twoway line betamid`dum'_permits_4ma_ffr_sw betamid`dum'_permits_4ma_fg_sw betamid`dum'_permits_4ma_lsap_sw h if h>=0 & h<=${hor}, ///
	color(navy cranberry dkorange) lwidth(medthick medium medium) lpattern(solid longdash shortdash) xtitle("") xlabel(0(4)$hor) || ///
	line zero 												    h if h>=0 & h<=${hor}, color(black) lpattern(solid) lwidth(vthin) ///
	graphregion(fcolor(white)) title(`: variable label dum`dum'',size(medsmall)) name(permits_4ma`dum', replace) legend(off) nodraw
	local permits_4ma`dum' `permits_4ma`dum'' permits_4ma`dum'
}

graph combine `permits_4ma19' `permits_4ma06', col(2) ycommon name(permit_robust, replace) xsize(5) ysize(7) title(Building permits, size(medsmall)) 

foreach y in rhpi permits_4ma{
	twoway line betamidbooms_`y'_ffr_sw betamidbooms_`y'_fg_sw betamidbooms_`y'_lsap_sw h if h>=0 & h<=${hor}, ///
	color(navy cranberry dkorange) lwidth(medthick medium medium) lpattern(solid longdash shortdash) xtitle("") xlabel(0(4)$hor) || ///
	line zero 												    h if h>=0 & h<=${hor}, color(black) lpattern(solid) lwidth(vthin) ///
	graphregion(fcolor(white)) title(`: variable label `y'',size(medsmall)) name(`y', replace) legend(off) nodraw
	local `y'dif ``y'' `y'
	}

graph combine `rhpidif' `permits_4madif', col(2) name(dif_robust, replace) xsize(5) ysize(7) nodraw title(Differential effect, size(medsmall))

graph combine rhpi_robust permit_robust dif_robust, rows(3) xsize(6.5) ysize(8)
cd "$outputFigures"
graph export "Figure_D4.pdf", replace

restore