*RANK ORDER OF PROPERTY CRIME RATES BY MSA
cd "$dataPath/ConstructedData"
set more off
use panel_use, clear

*Rank of crime rates
xtset msa_num time
egen rank_crime = rank(prop_crime) if sample & prop_crime!=., by(time)


*Average rank by boom
foreach z in rank_crime{
	gen `z'_avg =.
}
foreach v in 06 19{
foreach z in rank_crime{
	bysort msa_num: egen `z'`v'_aux = mean(`z') if dum`v'==1
	bysort msa_num: egen `z'`v'_aux2 = mean(`z'`v'_aux)
	bysort msa_num: gen `z'`v'_avg = `z'`v'_aux2 
	bysort msa_num: replace `z'_avg = `z'`v'_aux if dum`v'==1 	
	drop `z'`v'_aux `z'`v'_aux2
}
}

foreach v in 1997q1 2003q4 2005q4 2006q4 2012q4 2019q4{
foreach z in rank_crime{
	bysort msa_num: egen `z'`v'_aux = mean(`z') if time==tq(`v')
	bysort msa_num: egen `z'`v'_aux2 = mean(`z'`v'_aux)
	bysort msa_num: gen `z'`v'_avg = `z'`v'_aux2 
	bysort msa_num: replace `z'_avg = `z'`v'_aux if time==tq(`v') 	
	drop `z'`v'_aux `z'`v'_aux2
}
}

spearman rank_crime06_avg rank_crime19_avg
correl rank_crime19_avg rank_crime06_avg

gen drank_crime_avg = rank_crime19_avg - rank_crime06_avg 
gen drank_crime_avg19_96 = rank_crime2019q4_avg - rank_crime1997q1_avg 
gen drank_crime_avg19_06 = rank_crime2019q4_avg - rank_crime2006q4_avg 
gen drank_crime_avg19_05 = rank_crime2019q4_avg - rank_crime2005q4_avg 
gen drank_crime_avg19_03 = rank_crime2019q4_avg - rank_crime2003q4_avg 
sum drank_crime_avg drank_crime_avg19_96 drank_crime_avg19_03 drank_crime_avg19_05 drank_crime_avg19_06 if time==tq(2019q4)


*Aggregate stats
sum drank_crime_avg if time==tq(2019q1),detail
tabstat drank_crime_avg, stat(mean min max sd p5 p10 p25 p50 p75 p90 p95) format(%9.1f)

preserve
foreach var in mean min max sd {
egen `var'_crime = `var'(drank_crime_avg)
format `var'_crime %9.0f
}

foreach var in  5 10 25 50 75 90 95 {
egen p`var'_crime = pctile(drank_crime_avg), p(`var')
format p`var'_crime %9.0f
}
g dup = _n
keep if dup == 1
keep mean_crime min_crime max_crime sd_crime p5_crime p10_crime p25_crime p50_crime p75_crime p90_crime p95_crime
order mean_crime min_crime max_crime sd_crime p5_crime p10_crime p25_crime p50_crime p75_crime p90_crime p95_crime

cd "$outputTables"
list
listtab * using "Table B1.tex", delim(&) rstyle(tabular)  replace
restore


*Table sorted by changes in ranking
drop group
egen group = group(drank_crime_avg msa_name)
replace group = -group

labmask group, values(msa_name)
tabstat msa drank_crime_avg if sample, by(group) format(%9.0f)
drop group

preserve
bysort msa : g dup_msa = _n
keep if dup_msa == 1
keep name drank_crime_avg
sort drank_crime_avg
g number = _n
keep if number <= 10
ren (name drank_crime_avg) (name_imp rank_imp)
save improvement, replace
restore

preserve
bysort msa : g dup_msa = _n
keep if dup_msa == 1
keep name drank_crime_avg
g minus_drank_crime_avg = -drank_crime_avg
sort minus_drank_crime_avg
g number = _n
keep if number <= 10
drop minus_drank_crime_avg
ren (name drank_crime_avg) (name_det rank_det)
save detorioration, replace
restore


preserve
use improvement, clear
merge 1:1 number using detorioration
drop number _merge
format rank_det %9.0f
format rank_imp %9.0f

order name_det rank_det name_imp rank_imp
list
cd "$outputTables"
listtab * using "Table B2.tex", delim(&) rstyle(tabular)  replace
restore