****************************************************************
***************** HFI MONETARY POLICY SHOCKS *******************
****************************************************************
*Create full daily dataset
clear
input ddate
10958
21894
end

tsset ddate
tsfill, full
format ddate %td
g day = day(ddate) //Daily
g mdate = mofd(ddate) //Monthly
format mdate %tm
g qdate = qofd(ddate) //Quarterly
format qdate %tq


*Merge with shocks
cd "$dataPath/RawData"
merge 1:1 ddate day using hfi_mp_shocks 
drop _merge
replace ffs_3m = ffr_shock if ddate<td(28jan2004) // because our daily shocks only start in 2004

*Descriptive stats for daily shocks
sum ffs_3m if mdate>=tm(1997m1) & mdate<=tm(2006m12) | ((mdate>=tm(2012m7) & mdate<=tm(2019m12))),detail 

preserve
keep if mdate>=tm(1997m1) & mdate<=tm(2006m12) | ((mdate>=tm(2012m7) & mdate<=tm(2019m12)))
drop if ffs_3m == .
foreach var in mean median min max sd {
egen `var'_ffs_3m = `var'(ffs_3m)
format `var'_ffs_3m %9.3f
}
g obs = _N
g counter = _n

g descriptive = .
replace descriptive = mean_ffs_3m   if counter == 1
replace descriptive = median_ffs_3m if counter == 2
replace descriptive = sd_ffs_3m     if counter == 3
replace descriptive = min_ffs_3m    if counter == 4
replace descriptive = max_ffs_3m    if counter == 5
replace descriptive = obs 		   if counter == 6
format descriptive %9.3f 
keep descriptive counter
keep if descriptive != .
cd "$dataPath/ConstructedData"
save hf_summary, replace
restore

******** APPLY GK APPROACH TO CREATE MONTHLY SHOCKS **********
*1. Create a cumulative daily surprise series (sum of surprises during the last 31 days and 90 days)
sort ddate
gen ffs_3m_sum = sum(ffs_3m)
gen ffs_3m_sum30 = (ffs_3m_sum-ffs_3m_sum[_n-30])
replace ffs_3m_sum30 = ffs_3m_sum if _n == 30
drop ffs_3m_sum
replace ffs_3m_sum30 = . if ddate<td(28jan2004)

*2. Take monthly and quarterly averages across each day of the month
	bysort qdate: egen ffs_3m_qavg = mean(ffs_3m_sum30) //Quarterly

*Create unique monthly dataset
bysort mdate: gen dup = cond(_N==1,0,_n)
sum dup
drop if dup>1
drop dup ddate day month year ffs_3m 

*Merge with GK shocks
cd "$dataPath/RawData"
merge 1:1 mdate using gk_mp_shocks,
drop _merge

*Compute quarterly shocks
bysort qdate: egen ff4_tc_qavg = mean(ff4_tc) 

*Take GK shocks before 2004m2 
replace ffs_3m_qavg  = ff4_tc_qavg if qdate<tq(2004q1)

sum ffs_3m_qavg  , det
bysort qdate : g dup_qdate = _n
keep if dup_qdate == 1


*Descriptive stats for quarterly shocks
sum ffs_3m_qavg if qdate>=tq(1997q1) & qdate<=tq(2006q4) | ((qdate>=tq(2012q3) & qdate<=tq(2019q4))),detail 

preserve
keep if qdate>=tq(1997q1) & qdate<=tq(2006q4) | ((qdate>=tq(2012q3) & qdate<=tq(2019q4)))
foreach var in mean median min max sd {
egen `var'_ffs_3m_qavg = `var'(ffs_3m_qavg)
format `var'_ffs_3m_qavg %9.3f
}
g obs = _N
g counter = _n

g descriptive = .
replace descriptive = mean_ffs_3m_qavg if counter == 1
replace descriptive = median_ffs_3m_qavg if counter == 2
replace descriptive = sd_ffs_3m_qavg     if counter == 3
replace descriptive = min_ffs_3m_qavg    if counter == 4
replace descriptive = max_ffs_3m_qavg    if counter == 5
replace descriptive = obs 		   if counter == 6
format descriptive %9.3f 
keep descriptive counter
keep if descriptive != .
ren descriptive descriptive_q
cd "$dataPath/ConstructedData"
save hf_quarterly_summary, replace
restore

**Saving Table D.1 in LaTex
preserve
cd "$dataPath/ConstructedData"
use hf_summary, clear
merge 1:1 counter using hf_quarterly_summary
drop _merge counter
cd "$outputTables"
list
listtab * using "Table D1.tex", delim(&) rstyle(tabular)  replace
restore


********* Figure D.2 ********
*NBER recessions

tsset mdate
gen NBERrec= 0
replace NBERrec = 1 if tin(2007m12,2009m6)

tsset qdate
replace NBERrec = 1 if tin(2007q4,2009q2)
gen zero=0


nbercycles ffs_3m_qavg if tin(1998q1,2019q4), file(nber2.do) replace
type nber2.do

twoway function y=.04,range(164 167) recast(area) color(gs12) base(-.2) || /// 
function y=.04,range(191 197) recast(area) color(gs12) base(-.2) || /// 
bar ffs_3m_qavg zero qdate if tin(1998q1,2019q4), ///
color(navy black) lpattern(solid dash) lwidth(medium vthin) xlabel(,format(%tq) ///
labsize(small)) ylabel(#8,labsize(small)) legend(off) graphregion(fcolor(white))

*Export graph
cd "$outputFigures"
graph export "Figure_D2.pdf", replace

