	***************************************************************************************************
	* Replication code for "Changing supply elasticities and US housing cycles" *
	*************************************************************************************************** 
	
	** Define working directory 
	clear all
	set more off
	
	***********************************************************************************
	global main "C:\Users\andrekal\Dropbox\Published papers\Changing supply elasticities and US housing cycles\Submissions\Journals\JMCB\Replication"	
	***********************************************************************************
	set scheme s1mono, permanently
	global dataPath 	  "$main\Data"
	global outputTables   "$main\Tables"
	global outputFigures  "$main\Figures"
	global codePath       "$main\Codes\Appendix"
	global mapPath        "$main\Codes\For SE and maps"
	
	** Packages needed **
	ssc install asrol
	ssc install estout
	ssc install labutil
	ssc install listtab
	ssc install maptile
	ssc install matmap
	ssc install nbercycles
	ssc install shp2dta
	ssc install spmap
	ssc install unique
	**********************
	
	** This is to do all data preparations
	do "$codePath\Data transformations.do"  

	*List of control variables in baseline specification
	global ctrls 	    "lrwage lrwage_unaval lrwage_wrluri ur lpop dep_ratio black_pop hispan_pop dlcpi dom_mig_pop int_mig_pop dlrmort_org l1.dlrinc_cap cv_inc_cap20"
 
 	***********************************************************************************************
	*    Table A.1:  Local housing cycles **
	***********************************************************************************************
	do "$codePath/Table A1.do"  
 
	***********************************************************************************************
	*    Table B.1 and Table B.2:  Rank order changes across booms **
	***********************************************************************************************
	do "$codePath/Table B1 and Table B2.do"  
 
	***********************************************************************************************
	*    Figure B.1:  Map of elasticities for the two booms **
	***********************************************************************************************
	do "$codePath/Figure B1.do"  

	***********************************************************************************************
	*    Figure C.1:  Using mass shootings as alternative IV **
	***********************************************************************************************
	do "$codePath/Figure C1.do"  

	***********************************************************************************************
	*    Figure C.2:  Keeping fixed effects constant across samples **
	***********************************************************************************************
	do "$codePath/Figure C2.do"  
	
	***********************************************************************************************
	*    Figure C.3:  Bartik-type instrument **
	***********************************************************************************************
	do "$codePath/Figure C3.do"  

	***********************************************************************************************
	*    Figure C.4:  Replacing WRLURI and UNAVAL with land-use regulation index**
	***********************************************************************************************
	do "$codePath/Figure C4.do"  

	***********************************************************************************************
	*    Figure C.5:  State-by-time fixed effects**
	***********************************************************************************************
	do "$codePath/Figure C5.do"  

	***********************************************************************************************
	*    Figure C.6:  Rolling window estimation **
	***********************************************************************************************
	do "$codePath/Figure C6.do"  

	***********************************************************************************************
	*    Figure D.2 and Table D.1:  Monetary shocks **
	***********************************************************************************************
	do "$codePath/Table D1 and Figure D2.do"  
	
	***********************************************************************************************
	*    Figure D.3:  One-year t-bill as monetary indicator**
	***********************************************************************************************
	global depvar "rhpi permits_4ma" 
	global ctrls_lp "l(1/4).(dlrhpi dlpermits_4ma dlrinc dur dlpop dlrwage dus_ebp) elast"	
	global M = 1000
	global hor = 20 	
	do "$codePath/Figure D3.do"  
	
	***********************************************************************************************
	*    Figure D.4:  Swanson (2021) surprises **
	***********************************************************************************************
	do "$codePath/Figure D4.do"  
	
	***********************************************************************************************
	*    Figure D.5:  Aggregation method of Gazzani and Vicondoa (2020) **
	***********************************************************************************************
	do "$codePath/Figure D5.do"  