cd "$dataPath/RawData"
use RawDataFull, clear

** Create data set excluding proprietary data
preserve
keep time year quarter msa msa_name name main_state prop_crime wrluri unaval wage ffs3m_shock land_reg ffr_sw fg_sw lsap_sw us_cpi us_gs1 us_gs2 ///
us_ebp fatal gazzani msa_num
save RawData_Excl_Moodys, replace
restore

** State identifier
egen statenr = group(main_state)
	
*Division indents
g division = 0 
replace division = 1 if main_state == "ME" | main_state == "VT" | main_state == "NH" | main_state == "MA" | main_state == "CT" | main_state == "RI" 
replace division = 2 if main_state == "NJ" | main_state == "NY" | main_state == "PA" 
replace division = 3 if main_state == "WI" | main_state == "IL" | main_state == "MI" | main_state == "IN" | main_state == "OH" 
replace division = 4 if main_state == "ND" | main_state == "SD" | main_state == "NE" | main_state == "KS" | main_state == "MN" | main_state == "IA" | main_state == "MO" 
replace division = 5 if main_state == "MD" | main_state == "DE" | main_state == "DC" | main_state == "WV" | main_state == "VA" | main_state == "NC" | main_state == "SC" | main_state == "GA" | main_state == "FL"
replace division = 6 if main_state == "KY" | main_state == "TN" | main_state == "MS" | main_state == "AL" 
replace division = 7 if main_state == "OK" | main_state == "TX" | main_state == "AR" | main_state == "LA" 
replace division = 8 if main_state == "MT" | main_state == "ID" | main_state == "WY" | main_state == "NV" | main_state == "UT" | main_state == "CO" | main_state == "AZ" | main_state == "NM"
replace division = 9 if main_state == "WA"  | main_state == "OR"  | main_state == "CA" |main_state == "HI"  | main_state == "AK"  

*Division-by-time FE
egen division_time = group(division time)

**Dummies to identify the two subsamples	
gen dum06 = (tin(1997q1,2006q4))
gen dum19 = (tin(2012q3,2019q4))
label var dum06 "1996-2006"
label var dum19 "2012-2019"

*Group-dummy used testing for equal coeffients
g group = 0 
replace group = 1 if dum19 == 1 
replace group = 2 if dum06 == 1 

xtset msa time
*Dummy for the full sample period
gen sample = 0
replace sample = 1 if tin(1997q1,2019q4)

*Variable to collect estimated elasticities
gen elast = .
	
**Dummy = 1 if mass shooting
gen dum_ftl = 0
replace dum_ftl =1 if fatal!=.
	
*Employment-population ratio	
g nfp_pop_wa = nfp/pop_wa

*Fraction of blacks and hispanics relative to total population
foreach v in black hispan {
	gen `v'_pop = `v'/(fem+male)*100
}
drop fem male black hispan 

*Domestic and international migration relative to population
qui foreach v in dom_mig int_mig{
	gen `v'_pop = `v'/pop*100
}

*Moving average of permits 
	by msa: gen permits_4ma = (permits + l1.permits + l2.permits + l3.permits)/4

*Deflate variables
foreach v in hpi wage mort_org {
	bysort msa: gen r`v' = `v'/cpi*100
}

*Deflate national house prices 
	gen us_rhpi  = 100*(us_hpi/us_cpi)

*Rebase real house prices to 1995q1
replace rhpi=100 if msa==27780 & time==tq(1995q1) /*No data for Johnstown in 1995q1*/

gen rhpi_ind=rhpi
forval i=1/254 {
	qui sum rhpi_ind if msa_num==`i' & time==tq(1995q1)
	local temp=r(mean)
	qui replace rhpi_ind=rhpi_ind*100/`temp' if msa_num==`i'
}

gen us_rhpi_ind=us_rhpi /*For the US aggregate*/
forval i=1/254 {
	qui sum us_rhpi_ind if msa_num==`i' & time==tq(1995q1)
	local temp=r(mean)
	qui replace us_rhpi_ind=us_rhpi_ind*100/`temp' if msa_num==`i'
}
sum rhpi_ind if time==tq(1995q1)
replace rhpi = rhpi_ind
replace us_rhpi = us_rhpi_ind
drop rhpi_ind us_rhpi_ind

**Real per capita income
g rinc_cap = rinc/pop

**Taking logs and first differences of logged variables
xtset msa time
foreach v in rhpi permits prop_crime rinc rinc_cap rwage pop cpi rmort_org permits_4ma {
    bysort msa: gen l`v'= log(`v')
	bysort msa: gen dl`v' = (l`v'-l1.l`v')*100 if l1.l`v'!=.
}

**Logs and first differences of US house prices
	bysort msa: gen us_lrhpi= log(us_rhpi)
	bysort msa: gen us_dlrhpi = (us_lrhpi-l1.us_lrhpi)*100 if l1.us_lrhpi !=.

**Differences of ratios 
xtset msa time
foreach v in ur us_gs1 us_gs2 us_ebp {
	bysort msa: gen d`v' = (`v'-l1.`v') if l1.`v'!=.
}

**Rolling window estimations of means and standard deviations
sort msa_num time
xtset msa_num time
bys msa_num (time) : asrol dlrinc_cap, stat(sd)   window(time -21 -1)  min(20) gen(dlrinc_cap_ma20_sd) 
bys msa_num (time) : asrol dlrinc_cap, stat(mean) window(time -21 -1)  min(20) gen(dlrinc_cap_ma20) 

***Coefficient of variation
g cv_inc_cap20 = dlrinc_cap_ma20_sd/dlrinc_cap_ma20 

*Interaction terms
foreach w in lrhpi lprop_crime lrinc lrwage dum_ftl {
foreach v in unaval wrluri {
	gen `w'_`v' = `w'*`v'
}
}

**Variables for local projections
sort msa_num time
xtset msa_num time
foreach v in ur home_vacant nfp_pop_wa {
forval j= 0/16 {
	by msa_num: gen d`j'`v'_cum = (F`j'.`v' - l1.`v') if `v'!=.
}
}

***********************************************************************
******************* For cross-sectional regressions *******************
***********************************************************************

*Create an index for income rebased to 1995q1
qui gen inc_pc = ninc/pop

sort msa_num time
gen inc_pc_ind = inc_pc
forval i=1/254 {
qui sum inc_pc_ind if msa_num ==`i' & time == tq(1995q1)
local temp=r(mean)
qui replace inc_pc_ind = inc_pc_ind*100/`temp' if msa_num ==`i'
}
gen hpinc_pc = hpi/inc_pc_ind*100

**Initial values of HPI and population density, as of 2012
sort msa_num time
xtset msa_num time
foreach w in rhpi hpinc_pc pop_density {
foreach v in 2006q4 2012q2 {
	qui by msa_num: gen `w'`v' = `w' if time==tq(`v')
	qui by msa_num: egen `w'`v'_aux = mean(`w'`v')
	qui by msa_num: replace `w'`v' = `w'`v'_aux
	qui drop `w'`v'_aux
}
}

*Cumulative growth rate of house prices between 2006 and 2012
gen drhpi12 = rhpi2012q2/rhpi2006q4*100-100
g land_reg_cs = land_reg

*Average values by boom
foreach z in rwage ur pop_density land_reg_cs  {
	gen `z'_avg =.
}

sort msa_num time
xtset msa_num time
foreach v in 06 19 {
foreach z in rwage ur pop_density land_reg_cs {
	bysort msa_num: egen `z'`v'_aux = mean(`z') if dum`v'==1
	bysort msa_num: egen `z'`v'_aux2 = mean(`z'`v'_aux)
	bysort msa_num: gen `z'`v'_avg = `z'`v'_aux2 
	bysort msa_num: replace `z'_avg = `z'`v'_aux if dum`v'==1 	
	drop `z'`v'_aux `z'`v'_aux2
}
}

*Change in averages between boom
foreach z in rwage pop_density land_reg_cs  {
	gen d`z'_booms = 100*(`z'19_avg - `z'06_avg)/`z'06_avg
}

foreach z in ur  {
	gen d`z'_booms = `z'19_avg - `z'06_avg
}


*****************************************************************
********************* For local-projections ********************* 
*****************************************************************
sort msa_num time
xtset msa_num time
bysort msa_num (time): gen t = _n

gen zero=0
gen h = t-1
global hor=20
replace h = . if h>${hor}

sort msa_num time

*Cumulative growth
sort msa_num time
xtset msa_num time
qui foreach v in rhpi permits_4ma {
qui forval j= 0/${hor} {
	by msa_num: gen d`j'l`v'_cum = (F`j'.l`v' - l1.l`v')*100 if l1.l`v'!=.
}
}


*Sample only booms
gen smpl_booms = 0
replace smpl_booms = 1 if dum06==1 | dum19==1

qui foreach v in betamid beta betaupp betalow{
qui foreach w in rhpi permits_4ma {
	gen `v'booms_`w'=.
	gen `v'06_`w'=.
	gen `v'19_`w'=.
}
}

***When using landreg as an to WRLURI and UNAVAL alternative in appendix

*A decline in the land-use regulation index represents a tightening in regulation (multiply by -1 to make it consistent with UNAVAL!)
replace land_reg = land_reg*(-1)
**Construct variables used to allocate values to each boom
qui gen land_reg_avg = .


**Allocate values to each time period within each book
foreach v in 06 19{
	qui bysort msa_num: egen land_reg`v'_aux = mean(land_reg) if dum`v'==1
	qui bysort msa_num: replace land_reg_avg = land_reg`v'_aux if dum`v'==1
	qui drop land_reg`v'_aux

}

qui bysort msa_num: egen land_reg_aux = mean(land_reg) if dum06==1
qui bysort msa_num: egen land_reg_avg06 = mean(land_reg_aux)
qui drop land_reg_aux

foreach w in lrhpi lrinc lrwage lprop_crime { 
	gen `w'_land_reg_avg = `w'*land_reg_avg
}

**Used for rolling window estimations
sort msa_num time

foreach v in elastroll elastupproll elastlowroll{
foreach r in 10 15 {
	gen `v'`r' = .
}
}

foreach v in elastroll elastupproll elastlowroll{
foreach r in 10 15 {
foreach p in p10 p50 p90 {
	gen `v'`r'_`p' = .
}
}
}

cd "$dataPath/ConstructedData"
save panel_use, replace


