*** Addding MSA centroids to calculate Conley (1999, 2008) standard errors that are robust to both
*** spatial correlation and autocorrelation
clear all
cd "$dataPath/RawData"
use msa_centroids, clear
replace msa = 14460  if msa == 14454
replace msa = 16980	 if msa == 16974
replace msa = 19100  if msa == 19124
replace msa = 19820  if msa == 19804
replace msa = 31080  if msa == 31084
replace msa = 33100  if msa == 48424
replace msa = 35620  if msa == 35084
replace msa = 37980  if msa == 48864
replace msa = 41860  if msa == 41884
replace msa = 42660  if msa == 42644
replace msa = 47900  if msa == 47894

cd "$dataPath/ConstructedData"
merge 1:m msa using panel_use
keep if _m == 3
drop _merge

** Employing the code developed by Hsiang (2010)
cd "$mapPath"
do ols_spatial_HAC.ado

** Dummies for MSA FE
forvalues i = 1(1)254 {
g msa_dum`i' = 0 
replace msa_dum`i' = 1 if msa_num == `i'
}


** Dummies for time FE
forvalues i = 36(1)243 {
g time_dum`i' = 0 
replace time_dum`i' = 1 if time == `i'
}
 
***Interactions
*1st stage
sort msa_num time
xtset msa_num time
foreach y in lrhpi lrhpi_unaval lrhpi_wrluri {
ivreghdfe `y' group#c.(l1.lpermits $ctrls lprop_crime lprop_crime_wrluri lprop_crime_unaval lrinc lrinc_wrluri lrinc_unaval) if (dum06 == 1 | dum19==1) & sample== 1 & wrluri != . & unaval != ., robust absorb(group##msa_num time)
g in_sample_`y' =  e(sample)
predict `y'_fit if in_sample_`y' == 1
replace `y'_fit = . if in_sample_`y' == 0
}

*2nd stage
foreach z in dum06 dum19 {
sort msa_num time
ols_spatial_HAC lpermits l(1/1).lpermits msa_dum* time_dum* $ctrls lrhpi_fit lrhpi_unaval_fit lrhpi_wrluri_fit if `z'==1 & sample==1, lat(lat) lon(longi) timevar(time) panelvar(msa) dist(161) lag(2) bartlett dropvar
eststo output`z'
}


**No interactions
preserve
drop lrhpi_fit

*1st stage
sort msa_num time
xtset msa_num time
foreach y in lrhpi {
ivreghdfe `y' group#c.(l1.lpermits $ctrls_no_int lprop_crime lrinc) if (dum06 == 1 | dum19==1) & sample== 1 & wrluri != . & unaval != ., robust absorb(group##msa_num time)
g in_sample_`y'_noint =  e(sample)
predict `y'_fit if in_sample_`y'_noint == 1
replace `y'_fit = . if in_sample_`y'_noint == 0
}

*2nd stage
foreach z in dum06 dum19 {
sort msa_num time
ols_spatial_HAC lpermits l(1/1).lpermits msa_dum* time_dum* $ctrls_no_int lrhpi_fit if `z'==1 & sample==1, lat(lat) lon(longi) timevar(time) panelvar(msa) dist(161) lag(2) bartlett dropvar
eststo output_no_int`z'
}
restore


cd "$outputTables"
esttab output_no_intdum06 output_no_intdum19 outputdum06 outputdum19 using Table_3_spatial.tex, keep(lrhpi_fit lrhpi_unaval_fit lrhpi_wrluri_fit L.lpermits)  order(lrhpi_fit lrhpi_unaval_fit lrhpi_wrluri_fit L.lpermits) f replace ///
b(2) se(2) sfmt(2) noobs se label coeflabels(lrhpi_fit "log(HPI)" lrhpi_unaval_fit "log(HPI) $\times$ UNAVAL" lrhpi_wrluri_fit "log(HPI) $\times$ WRLURI" L.lpermits "log(H$_{t-1}$)")  mtitles("1996-2006" "2012-2019" "1996-2006" "2012-2019") star(* 0.10 ** 0.05 *** 0.01) nonum type     	

esttab output_no_intdum06 output_no_intdum19 outputdum06 outputdum19 using Table_3_spatial.tex, drop(*) f a 	noobs nomtitles nonum wrap nogaps

esttab output_no_intdum06 output_no_intdum19 outputdum06 outputdum19 using Table_3_spatial.tex, drop(*) f a ///
noobs scalars("N Observations" "msas MSAs" "cdf Cragg-Donald F-test"  "widstat Kleibergen-Paap (robust) F-test") sfmt(%9.0fc %9.0fc %9.2fc %9.2fc) nomtitles nonum wrap nolines nogaps


***Testing equal supply elasticities across booms
sort msa_num time
xtset msa_num time
g lag_lpermits = l1.lpermits
g lag_dlrinc_cap = l1.dlrinc_cap

foreach var in  lag_lpermits lrwage lrwage_unaval lrwage_wrluri ur lpop dep_ratio black_pop hispan_pop dlcpi dom_mig_pop int_mig_pop dlrmort_org lag_dlrinc_cap cv_inc_cap20 lrhpi_fit lrhpi_unaval_fit lrhpi_wrluri_fit {
g `var'_06 = 0 
replace `var'_06  =  `var' if dum06 == 1

g `var'_19 = 0 
replace `var'_19 = `var' if dum19 == 1
}


** Dummies for MSA FE
drop msa_dum*
forvalues i = 1(1)254 {
g msa_dum`i'_06 = 0 
replace msa_dum`i'_06 = 1 if msa_num == `i' & dum06 == 1
g msa_dum`i'_19 = 0 
replace msa_dum`i'_19 = 1 if msa_num == `i' & dum19 == 1
}

global ctrls_spatial "lrwage_06 lrwage_unaval_06 lrwage_wrluri_06 ur_06 lpop_06 dep_ratio_06 black_pop_06 hispan_pop_06 dlcpi_06 dom_mig_pop_06 int_mig_pop_06 dlrmort_org_06 lag_dlrinc_cap_06 cv_inc_cap20_06 lrwage_19 lrwage_unaval_19 lrwage_wrluri_19 ur_19 lpop_19 dep_ratio_19 black_pop_19 hispan_pop_19 dlcpi_19 dom_mig_pop_19 int_mig_pop_19 dlrmort_org_19 lag_dlrinc_cap_19 cv_inc_cap20_19"

ols_spatial_HAC lpermits lag_lpermits_06 lag_lpermits_19 msa_dum* time_dum* $ctrls_spatial lrhpi_fit_06 lrhpi_fit_19 lrhpi_unaval_fit_06 lrhpi_unaval_fit_19 lrhpi_wrluri_fit_06 lrhpi_wrluri_fit_19  if (dum06 == 1 | dum19 == 1) & sample==1, lat(lat) lon(longi) timevar(time) panelvar(msa) dist(161) lag(2) bartlett dropvar

preserve
sum wrluri if dum06 == 1 | dum19 == 1, det
local p10_wrluri = round(r(p10),0.01)
local med_wrluri = round(r(p50),0.01)
local p90_wrluri = round(r(p90),0.01)

sum unaval if dum06 == 1 | dum19 == 1, det
local p10_unaval = round(r(p10),0.01)
local med_unaval = round(r(p50),0.01)
local p90_unaval = round(r(p90),0.01)


matrix effects = J(3,3,.)

lincom (_b[lrhpi_fit_06] + _b[lrhpi_unaval_fit_06]*`p10_unaval' + _b[lrhpi_wrluri_fit_06]*`p10_wrluri') - (_b[lrhpi_fit_19] + _b[lrhpi_unaval_fit_19]*`p10_unaval' + _b[lrhpi_wrluri_fit_19]*`p10_wrluri')
matrix effects[1,1] = r(estimate)	
matrix effects[1,2] = r(se)	
matrix effects[1,3] = r(p)	

lincom (_b[lrhpi_fit_06] + _b[lrhpi_unaval_fit_06]*`med_unaval' + _b[lrhpi_wrluri_fit_06]*`med_wrluri') - (_b[lrhpi_fit_19] + _b[lrhpi_unaval_fit_19]*`med_unaval' + _b[lrhpi_wrluri_fit_19]*`med_wrluri')
matrix effects[2,1] = r(estimate)	
matrix effects[2,2] = r(se)	
matrix effects[2,3] = r(p)	

lincom (_b[lrhpi_fit_06] + _b[lrhpi_unaval_fit_06]*`p90_unaval' + _b[lrhpi_wrluri_fit_06]*`p90_wrluri') - (_b[lrhpi_fit_19] + _b[lrhpi_unaval_fit_19]*`p90_unaval' + _b[lrhpi_wrluri_fit_19]*`p90_wrluri')
matrix effects[3,1] = r(estimate)	
matrix effects[3,2] = r(se)	
matrix effects[3,3] = r(p)	

svmat effects, names(effects)
keep effects* 
keep if effects1 != .
ren (effects1 effects2 effects3) (diff se pval)
format diff %9.2f
format se %9.2f
format pval %9.2f

restore



