*SUMMARY TABLES
cd "$dataPath/ConstructedData"
set more off
use panel_use, clear

*** To esnsure same sample as CS regression for Land reg.
eststo clear
xtset msa_num time
foreach z in dum06 dum19 {
sort msa_num time

sort msa_num time
ivreghdfe lpermits l(1/1).lpermits $ctrls  (lrhpi lrhpi_unaval lrhpi_wrluri = lprop_crime lprop_crime_wrluri lprop_crime_unaval lrinc lrinc_wrluri lrinc_unaval) if `z'==1 & sample==1, robust absorb(msa_num time)

g in_sample =  e(sample)
bysort msa_num in_sample: g msa_nr = _n 
g msa_`z' = (msa_nr == 1 & in_sample == 1)

qui replace elast =_b[lrhpi] + _b[lrhpi_unaval]*unaval + _b[lrhpi_wrluri]*wrluri if `z'==1 & sample==1 

drop in_sample msa_nr 
}

replace elast = 0 if elast<0

g elast06_help = elast if dum06 == 1
bysort msa_num : egen elast06 = median(elast06)
g elast19_help = elast if dum19 == 1
bysort msa_num : egen elast19 = median(elast19)

g delast_booms = 100*(elast19-elast06)/elast06 
replace land_reg_cs  = . if delast_booms == .
replace dland_reg_cs = . if delast_booms == .
******************

xtset msa_num time 
g lpop_density   = log(pop_density)
sort msa_num time 
bysort msa_num: g d4lpop_density = (lpop_density - l4.lpop_density)*100 

replace land_reg_cs = land_reg_cs*100
replace land_reg_cs  = . if time != tq(2000q1) & time != tq(2014q1)
replace dland_reg_cs = . if  time != tq(2014q1)

****************
*** Table A1 ***
****************
preserve
keep if year >= 1997 & year <= 2019
g counter = _n
g mean_vars = .
g obs_vars = .
g sd_vars = .
g min_vars = .
g max_vars = .

local j = 1 
foreach v in lrhpi hpinc_pc lpermits unaval wrluri lrinc lrwage lcpi lrmort_org ur lpop lpop_density dep_ratio black_pop hispan_pop dom_mig_pop ///
int_mig_pop lprop_crime land_reg_cs dlrhpi dlrinc dlrwage dlcpi dlrmort_org dur dlpop d4lpop_density dland_reg_cs {
	di `j'
	egen mean_`v' = mean(`v')
	replace mean_vars = mean_`v' if counter == `j'
	egen sd_`v' = sd(`v')
	replace sd_vars = sd_`v' if counter == `j'
	egen max_`v' = max(`v')
	replace max_vars = max_`v' if counter == `j'
	egen min_`v' = min(`v')
	replace min_vars = min_`v' if counter == `j'	
	su `v'
	replace obs_vars = r(N) if counter == `j'
	local ++j
}
keep obs_vars mean_vars sd_vars min_vars max_vars
keep if obs_vars  != .

format mean_vars %9.1f
format sd_vars   %9.1f
format min_vars  %9.1f
format max_vars  %9.1f

order obs_vars mean_vars sd_vars min_vars max_vars
list

cd "$outputTables"
listtab * using "Table A1_paper.tex", delim(&) rstyle(tabular)  replace
restore

****************
*** Table A2 ***
****************
preserve
keep if year >= 1997 & year <= 2006
g counter = _n
g mean_vars = .
g obs_vars = .
g sd_vars = .
g min_vars = .
g max_vars = .

local j = 1 
foreach v in lrhpi hpinc_pc lpermits unaval wrluri lrinc lrwage lcpi lrmort_org ur lpop lpop_density dep_ratio black_pop hispan_pop dom_mig_pop ///
int_mig_pop lprop_crime land_reg_cs dlrhpi dlrinc dlrwage dlcpi dlrmort_org dur dlpop d4lpop_density  {
	di `j'
	egen mean_`v' = mean(`v')
	replace mean_vars = mean_`v' if counter == `j'
	egen sd_`v' = sd(`v')
	replace sd_vars = sd_`v' if counter == `j'
	egen max_`v' = max(`v')
	replace max_vars = max_`v' if counter == `j'
	egen min_`v' = min(`v')
	replace min_vars = min_`v' if counter == `j'	
	su `v'
	replace obs_vars = r(N) if counter == `j'
	local ++j
}
keep obs_vars mean_vars sd_vars min_vars max_vars
keep if obs_vars  != .

format mean_vars %9.1f
format sd_vars   %9.1f
format min_vars  %9.1f
format max_vars  %9.1f

order obs_vars mean_vars sd_vars min_vars max_vars
list

cd "$outputTables"
listtab * using "Table A2_paper.tex", delim(&) rstyle(tabular)  replace
restore

****************
*** Table A3 ***
****************
preserve
keep if dum19 == 1
g counter = _n
g mean_vars = .
g obs_vars = .
g sd_vars = .
g min_vars = .
g max_vars = .

local j = 1 
foreach v in lrhpi hpinc_pc lpermits unaval wrluri lrinc lrwage lcpi lrmort_org ur lpop lpop_density dep_ratio black_pop hispan_pop dom_mig_pop ///
int_mig_pop lprop_crime land_reg_cs dlrhpi dlrinc dlrwage dlcpi dlrmort_org dur dlpop d4lpop_density  {
	di `j'
	egen mean_`v' = mean(`v')
	replace mean_vars = mean_`v' if counter == `j'
	egen sd_`v' = sd(`v')
	replace sd_vars = sd_`v' if counter == `j'
	egen max_`v' = max(`v')
	replace max_vars = max_`v' if counter == `j'
	egen min_`v' = min(`v')
	replace min_vars = min_`v' if counter == `j'	
	su `v'
	replace obs_vars = r(N) if counter == `j'
	local ++j
}
keep obs_vars mean_vars sd_vars min_vars max_vars
keep if obs_vars  != .

format mean_vars %9.1f
format sd_vars   %9.1f
format min_vars  %9.1f
format max_vars  %9.1f

order obs_vars mean_vars sd_vars min_vars max_vars
list

cd "$outputTables"
listtab * using "Table A3_paper.tex", delim(&) rstyle(tabular)  replace
restore