	*****************************************************************************
	* Replication code for "Changing supply elasticities and US housing cycles" *
	***************************************************************************** 
	
	** Define working directory 
	clear all
	set more off
	
	**************************************************************************************************************************************************
	global main "C:\Users\andrekal\Dropbox\Published papers\Changing supply elasticities and US housing cycles\Submissions\Journals\JMCB\Replication"	
	**************************************************************************************************************************************************
	set scheme s1mono, permanently
	global dataPath 	  "$main\Data"
	global outputTables   "$main\Tables"
	global outputFigures  "$main\Figures"
	global codePath       "$main\Codes\Paper"
	global mapPath        "$main\Codes\For SE and maps"
	
	** Packages needed **
	ssc uninstall asrol
	ssc install asrol
	ssc install estout
	ssc install labutil
	ssc install listtab
	ssc install maptile
	ssc install matmap
	ssc install nbercycles
	ssc install shp2dta
	ssc install spmap
	ssc install unique
	**********************
		
	** This is to do all data preparations
	do "$codePath\Data transformations.do"  
					
	***********************************************************************************************
	*    Table 1:  Relationship between wage growth and instruments**
	***********************************************************************************************
	global ctrls_no_int "lrwage ur lpop dep_ratio black_pop hispan_pop dlcpi dom_mig_pop int_mig_pop dlrmort_org l1.dlrinc_cap cv_inc_cap20" 

	do "$codePath/Table 1.do"  

	***********************************************************************************************
	*    Table 2:  Predicting future demand**
	***********************************************************************************************
	do "$codePath/Table 2.do"  
	
	***********************************************************************************************
	*    Table 3:  Baseline results for supply elasticity**
	***********************************************************************************************
	global ctrls 	    "lrwage lrwage_unaval lrwage_wrluri ur lpop dep_ratio black_pop hispan_pop dlcpi dom_mig_pop int_mig_pop dlrmort_org l1.dlrinc_cap cv_inc_cap20"
	global ctrls_no_int "lrwage ur lpop dep_ratio black_pop hispan_pop dlcpi dom_mig_pop int_mig_pop dlrmort_org l1.dlrinc_cap cv_inc_cap20" 

	do "$codePath/Table 3.do"  

	***********************************************************************************************
	*    Figure 3:  Boxplots for supply elasticities from baseline **
	***********************************************************************************************
	do "$codePath/Figure 3.do"  

	***********************************************************************************************
	*    Figure 4:  Percentage change in elasticities across booms **
	***********************************************************************************************
	do "$codePath/Figure 4.do"  
	
	***********************************************************************************************
	*    Table 4 : Explaining cross sectional variation**
	***********************************************************************************************
	global ctrls_cs     "dpop_density_booms drwage_booms dur_booms hpinc_pc2012q2 pop_density2012q2"
	
	do "$codePath/Table 4.do"  
	
	***********************************************************************************************
	*    Figure 5: Impulse response function for local projection analysis**
	***********************************************************************************************
	global depvar "rhpi permits_4ma" 
	global ctrls_lp "l(1/4).(dlrhpi dlpermits_4ma dlrinc dur dlpop dlrwage dus_ebp) elast"	
	global M = 1000
	global hor = 20

	do "$codePath/Figure 5.do"  

	*************************************************************************************************
	*    Table A.1, Table A.2, and Table A.3: Summary stats for full sample and the two subsamples **
	*************************************************************************************************
	do "$codePath/Table A1, Table A2, and Table A3.do"  

	
	
	
	